@@ -1,7 +1,4 @@
-import json
-
 import numpy as np
-import pandas as pd
 from pandas.api.types import (
     is_bool_dtype,
     is_categorical_dtype,
@@ -103,3 +100,21 @@ def create_description(series, n_options=100):
     }
 
     return input_description
+
+
+def vega_sanitize(var, datatype=None):
+    """Sanitize string for use as variable name in Vega-Lite/Altair
+
+    For background, see: https://github.com/altair-viz/altair/issues/284
+    """
+    var = var.replace(".", "\\.")
+    var = var.replace("[", "\\[")
+    var = var.replace("]", "\\]")
+    if datatype:
+        var = var + ":" + datatype
+    return var
+
+
+def replace_unserializable(series):
+    """Transform numpy types that can't be serialized to ones that can"""
+    return series.replace({np.nan: None, np.inf: None})
